import Mutex from "../utils/mutex";
import { BlockEvents, NFTEvent, NFTExecutable, NFTEventMap, APICallReturn } from "../types/types";
import { ContractService } from "../services/contractService";
export declare class NFTExecuteClass implements NFTExecutable {
    nftEvent: NFTEvent;
    executionStatus: "idle" | "running" | "success" | "fail";
    blockProcessed: number[];
    callFunc: (nftEvent: NFTEvent) => Promise<APICallReturn<number[]>>;
    constructor(nftEvent: NFTEvent, callFunc: (nftEvent: NFTEvent) => Promise<APICallReturn<number[]>>);
    execute(): Promise<void>;
    executeEvents: () => Promise<void>;
}
interface NFTEventFilters {
    paymentReceived: string;
}
export declare class NFTEventProcessor {
    blockNumberToIDMap: {
        [index: string]: number;
    };
    runningEventList: NFTExecuteClass[];
    collectedBlockList: BlockEvents[];
    blockEventCountMap: {
        [index: number]: number;
    };
    nftEventMap: NFTEventMap;
    isNFTRunning: {
        [nftID: string]: boolean;
    };
    completedBlockList: number[];
    blockToWriteList: number[];
    shouldRunTick: boolean;
    nextRunTime: number;
    RUN_INTERVAL: number;
    collectedBlockMutex: Mutex;
    filterToParamMap: {
        [index: string]: (blockNumber: number, param: any) => NFTEvent;
    };
    filterToParamBatchMap: {
        [idnex: string]: (blockNumber: number, param: any) => NFTEvent[];
    };
    filterToEventIDMap: {};
    filters: NFTEventFilters | undefined;
    contractService: ContractService;
    callFunc: (nftEvent: NFTEvent) => Promise<APICallReturn<number[]>>;
    constructor(contractService: ContractService, callFunc: (nftEvent: NFTEvent) => Promise<APICallReturn<number[]>>);
    setup: () => Promise<void>;
    addCollectedBlockInternal: (blockNumber: number, waitingStatus: boolean) => number;
    collectEvents: (waitingStatus: boolean, nftEventList: NFTEvent[]) => Promise<void>;
    collectBlock: (blockNumber: number, waitingStatus: boolean) => Promise<void>;
    saveCompletedBlocks: () => void;
    addNFTEvents: (nftEvent: NFTEvent) => void;
    handleCompletedEvents: () => void;
    getReadyBlocksFromCollectedList: () => Promise<BlockEvents[]>;
    addNFTEventsFromReadyBlocks: (readyBlockList: BlockEvents[]) => void;
    getBlockToWriteList: () => number[];
    clearBlockToWriteList: () => void;
    getAndClearBlockToWriteList: () => number[];
    setRunTick: (flag: boolean) => void;
    update: () => Promise<void>;
}
export {};
