"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.appModifierSchema = exports.appPayloadSchema = exports.portSchema = exports.envSchema = exports.volumeSchema = exports.resourceSchema = exports.attribSchema = void 0;
var joi_1 = __importDefault(require("joi"));
exports.attribSchema = joi_1.default.object({
    name: joi_1.default.string().required(),
    condition: joi_1.default.string().required(),
    conditionDescription: joi_1.default.string(),
    defaultValue: joi_1.default.string(),
});
exports.resourceSchema = joi_1.default.object({
    memory: joi_1.default.number().required(),
    cpu: joi_1.default.number().required(),
    disk: joi_1.default.number(),
});
exports.volumeSchema = joi_1.default.object({
    mountPath: joi_1.default.string().required(),
    name: joi_1.default.string().required(),
});
exports.envSchema = joi_1.default.object({
    name: joi_1.default.string().required(),
    value: joi_1.default.string().required(),
});
exports.portSchema = joi_1.default.object({
    containerPort: joi_1.default.string().pattern(new RegExp("^[0-9]+$")),
    servicePort: joi_1.default.string().pattern(new RegExp("^[0-9]+$")),
    hostURL: joi_1.default.object({
        urlString: joi_1.default.string(),
        createMode: joi_1.default.string().valid("CUSTOM", "CREATE"),
    }),
});
exports.appPayloadSchema = joi_1.default.object({
    appName: joi_1.default.string().required(),
    nftID: joi_1.default.string().required(),
    namespace: joi_1.default.string().required(),
    containers: joi_1.default.array()
        .items(joi_1.default.object({
        name: joi_1.default.string().required(),
        image: joi_1.default.string().required(),
        tcpPorts: joi_1.default.array().items(exports.portSchema).required(),
        httpPorts: joi_1.default.array().items(exports.portSchema).required(),
        args: joi_1.default.array().items(joi_1.default.string()),
        commands: joi_1.default.array().items(joi_1.default.string()),
        envVariables: joi_1.default.array().items(exports.envSchema),
        volumeMounts: joi_1.default.array().items(exports.volumeSchema),
        resourceLimits: exports.resourceSchema.required(),
        resourceRequests: exports.resourceSchema.required(),
    }))
        .required(),
    replicaCount: joi_1.default.number(),
    whitelistedIps: joi_1.default.array().items(joi_1.default.string()),
    persistence: joi_1.default.array()
        .items(joi_1.default.object({
        name: joi_1.default.string().required(),
        accessMode: joi_1.default.string().valid("ReadWriteOnce").required(),
        storageType: joi_1.default.string()
            .valid("standard", "ssd-sc")
            .required(),
        storageSize: joi_1.default.string(),
    }))
        .required(),
    status: joi_1.default.string().allow(""),
    privateImage: joi_1.default.object({
        registry: joi_1.default.string().required(),
        username: joi_1.default.string().required(),
        password: joi_1.default.string().required(),
    }),
    attribVarList: joi_1.default.array().items(exports.attribSchema),
});
exports.appModifierSchema = joi_1.default.object({
    modAttribVar: joi_1.default.object()
        .pattern(/^[a-zA-Z][a-zA-Z0-9]*$/, joi_1.default.string())
        .required(),
    contractParam: {
        resourceCount: joi_1.default.array().items(joi_1.default.number()),
        resourceType: joi_1.default.array().items(joi_1.default.number()),
        multiplier: joi_1.default.object().pattern(/^.*$/, joi_1.default.array().items(joi_1.default.number())),
    },
    misc: joi_1.default.any().allow({}).optional(),
    loggerURL: joi_1.default.string().allow(""),
});
